# ENCODE: Encoding NetFlows for Network Anomaly Detection
A python package for learning contextual features from NetFlow data using only three features (number of bytes sent, number of packets sent and the duration of flow). The learned contextual features can help aid with learning more accurate machine learning models for network anomaly detection.

This python package can be easily installed via PyPi: https://pypi.org/project/encode-netflow/


